import React from 'react'

import {
  VStack,
  TableContainer,
  Table,
  Thead,
  Tr,
  Th,
  Tbody,
  Td,
  Text,
  TableCaption,
  Tooltip,
  HStack,
  Icon,
  IconButton,
  Spinner,
} from '@chakra-ui/react'
import { FaEdit, FaEye, FaPlus } from 'react-icons/fa'
import { match } from 'ts-pattern'

import { Link, routes } from '@redwoodjs/router'

import { Pattern } from 'src/models'

import { AddPatternButton } from './add-pattern'
import { GetPatternsQuery } from './query-builder'
import { RemovePatternIconButton } from './remove-pattern'

const tableHeaders = ['Titulo', 'Descripcion', '#Implementaciones', '']

export const Patterns: React.FC = () => {
  const patternsQuery = GetPatternsQuery.useQuery({})

  return (
    <VStack alignItems="flex-start" spacing="2">
      <Text fontWeight="bold" px="1">
        Patrones
      </Text>
      <TableContainer>
        <Table variant="striped" size="lg">
          <TableCaption>Patrones disponibles</TableCaption>
          <Thead>
            <Tr>
              {tableHeaders.map((header, index) => (
                <Th color="gray.500" key={`th-${index}`}>
                  {header}
                </Th>
              ))}
            </Tr>
          </Thead>
          <Tbody>
            {match(patternsQuery)
              .with({ status: 'success', data: [] }, () => (
                <Text>No se encontraron patrones</Text>
              ))
              .with({ status: 'success' }, ({ data }) =>
                data.map((pattern, index) => (
                  <Tr key={`pattern-${pattern.title}-${index}`}>
                    <Td>
                      <Link to={routes.pattern({ id: pattern.id })}>
                        {pattern.title}
                      </Link>
                    </Td>
                    <Td>
                      <Tooltip label={pattern.description} hasArrow>
                        <Text isTruncated maxW="sm">
                          {pattern.description}
                        </Text>
                      </Tooltip>
                    </Td>
                    <Td>
                      <Text textAlign="center">
                        {pattern.numberOfImplementations}
                      </Text>
                    </Td>
                    <Td>
                      <ActionsRow pattern={pattern} />
                    </Td>
                  </Tr>
                ))
              )
              .with({ status: 'loading' }, () => (
                <Tr>
                  <Td colSpan={tableHeaders.length}>
                    <HStack justifyContent="center">
                      <Spinner />
                    </HStack>
                  </Td>
                </Tr>
              ))
              .otherwise(() => null)}
          </Tbody>
        </Table>
      </TableContainer>
      <HStack w="full" justifyContent="flex-end">
        <AddPatternButton />
      </HStack>
    </VStack>
  )
}

type ActionsRowProps = {
  pattern: Pattern
}
const ActionsRow: React.FC<ActionsRowProps> = ({ pattern }) => {
  return (
    <HStack spacing="0">
      <Link to={routes.pattern({ id: pattern.id })}>
        <IconButton
          aria-label="view pattern"
          variant="unstyled"
          icon={<Icon as={FaEye} />}
        />
      </Link>
      <IconButton
        aria-label="add pattern"
        variant="unstyled"
        icon={<Icon as={FaPlus} />}
      />
      <IconButton
        aria-label="edit pattern"
        variant="unstyled"
        icon={<Icon as={FaEdit} />}
      />
      <RemovePatternIconButton pattern={pattern} />
    </HStack>
  )
}
