import React from 'react'

import {
  IconButtonProps,
  IconButton,
  Icon,
  useDisclosure,
  AlertDialog,
  AlertDialogOverlay,
  AlertDialogContent,
  AlertDialogHeader,
  AlertDialogBody,
  AlertDialogFooter,
  Button,
  Text,
} from '@chakra-ui/react'
import { FaTrash } from 'react-icons/fa'
import { useQueryClient } from 'react-query'

import { Pattern } from 'src/models'

import { DeletePatternMutation, GetPatternsQuery } from '../query-builder'

export type RemovePatternIconButtonProps = {
  pattern: Pattern
} & Partial<IconButtonProps>

export const RemovePatternIconButton: React.FC<
  RemovePatternIconButtonProps
> = ({ pattern, ...props }) => {
  const queryClient = useQueryClient()
  const { isOpen, onOpen, onClose } = useDisclosure()
  const cancelRef = React.useRef<HTMLButtonElement>(null)

  const deletePatternMutation = DeletePatternMutation.useMutation({
    onSuccess: () => {
      queryClient.invalidateQueries(GetPatternsQuery.getKey({}))
    },
  })

  const handleDeletePattern = () => {
    deletePatternMutation.mutate({ id: pattern.id })
  }
  return (
    <>
      <IconButton
        aria-label="view pattern"
        variant="unstyled"
        icon={<Icon as={FaTrash} />}
        {...props}
        onClick={onOpen}
      />
      <AlertDialog
        isOpen={isOpen}
        onClose={onClose}
        leastDestructiveRef={cancelRef}
      >
        <AlertDialogOverlay>
          <AlertDialogContent>
            <AlertDialogHeader fontSize="lg" fontWeight="bold">
              Eliminar este patron?
            </AlertDialogHeader>
            <AlertDialogBody>
              <Text>
                Si eliminas el patron <Text as="b">{pattern.title}</Text> todos
                sus datos asociados seran eliminados.
              </Text>
            </AlertDialogBody>
            <AlertDialogFooter>
              <Button ref={cancelRef} variant="ghost" onClick={onClose}>
                Cancelar
              </Button>
              <Button variant="solid" onClick={handleDeletePattern} ml="3">
                Eliminar
              </Button>
            </AlertDialogFooter>
          </AlertDialogContent>
        </AlertDialogOverlay>
      </AlertDialog>
    </>
  )
}
